@@ -16,6 +16,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -394,7 +398,7 @@ static int set_options(struct udev *udev,
                         break;
 
                 case 'V':
-                        printf("%i\n", VERSION);
+                        printf("%s\n", VERSION);
                         exit(0);
 
                 case 'x':
